Class: Saml::Kit::NullAssertion

Inherits:
Object
  • Object
show all
Includes:
Translatable, Validatable
Defined in:
lib/saml/kit/null_assertion.rb

Overview

This class is an implementation of the Null Object pattern for when a Response is missing an Assertion.

Instance Method Summary collapse

Methods included from Validatable

#each_error

Instance Method Details

#attributes ⇒ Object



23
24
25
# File 'lib/saml/kit/null_assertion.rb', line 23

def attributes
  []
end

#audiences ⇒ Object



35
36
37
# File 'lib/saml/kit/null_assertion.rb', line 35

def audiences
  []
end

#decryptable? ⇒ Boolean

Returns:

  • (Boolean)


43
44
45
# File 'lib/saml/kit/null_assertion.rb', line 43

def decryptable?
  false
end

#encrypted? ⇒ Boolean

Returns:

  • (Boolean)


39
40
41
# File 'lib/saml/kit/null_assertion.rb', line 39

def encrypted?
  false
end

#expired_at ⇒ Object



31
32
33
# File 'lib/saml/kit/null_assertion.rb', line 31

def expired_at
  Time.at(0)
end

#invalid ⇒ Object



55
56
57
# File 'lib/saml/kit/null_assertion.rb', line 55

def invalid
  errors.add(:assertion, error_message(:invalid))
end

#issuer ⇒ Object



13
# File 'lib/saml/kit/null_assertion.rb', line 13

def issuer; end

#name ⇒ Object



59
60
61
# File 'lib/saml/kit/null_assertion.rb', line 59

def name
  'NullAssertion'
end

#name_id ⇒ Object



15
# File 'lib/saml/kit/null_assertion.rb', line 15

def name_id; end

#present? ⇒ Boolean

Returns:

  • (Boolean)


47
48
49
# File 'lib/saml/kit/null_assertion.rb', line 47

def present?
  false
end

#signature ⇒ Object



21
# File 'lib/saml/kit/null_assertion.rb', line 21

def signature; end

#signed? ⇒ Boolean

Returns:

  • (Boolean)


17
18
19
# File 'lib/saml/kit/null_assertion.rb', line 17

def signed?
  false
end

#started_at ⇒ Object



27
28
29
# File 'lib/saml/kit/null_assertion.rb', line 27

def started_at
  Time.at(0)
end

#to_xml(*_args) ⇒ Object



51
52
53
# File 'lib/saml/kit/null_assertion.rb', line 51

def to_xml(*_args)
  ''
end